@@ -3,7 +3,6 @@ from ..imports import *
 # -------- Public API drop-ins that mirror your originals --------
 from .filter_params import *
 from .file_filters import *
-from .file_utils import *
 from .pdf_utils import *
 # ---------------------------------------------------------------------------
 # NOTE: The following helper functions must be provided elsewhere:
@@ -238,68 +237,6 @@ def read_shape_file(path: str) -> Union[gpd.GeoDataFrame, None]:
     return None
 
 
-def collect_filepaths(
-    inputs: Union[str, List[str]],
-    exclude_dirs: set[str] = None,
-    exclude_file_patterns: set[str] = None,
-    exclude_types: set[str] = None
-) -> List[str]:
-    """
-    Given a path or list of paths, return a list of all file paths under them.
-    - If an input is a file, it's included (unless it matches an exclude pattern).
-    - If an input is a directory, walk it recursively:
-        • Skip any subdirectory named in `exclude_dirs`
-        • Skip any file whose name matches one of `exclude_file_patterns`
-    """
-    re_initialize_skip_mgr(exclude_types=exclude_types,
-                           exclude_file_patterns=exclude_file_patterns,
-                           exclude_dirs=exclude_dirs)
-
-
-    # Normalize to list
-    if isinstance(inputs, str):
-        paths_to_scan = [inputs]
-    else:
-        paths_to_scan = list(inputs)
-
-    all_files: List[str] = []
-
-
-
-    def _collect_from_dir(dirpath: str):
-        for dirpath_root, dirnames, filenames in os.walk(dirpath):
-            # Remove any excluded subdirectories from os.walk
-            dirnames[:] = [d for d in dirnames if d not in exclude_dirs]
-
-            for fname in filenames:
-                if should_skip(exclude_item=fname,
-                               exclude_types=True,
-                               exclude_file_patterns=True):
-                    continue
-                full = os.path.join(dirpath_root, fname)
-                all_files.append(full)
-
-    for p in paths_to_scan:
-        if not os.path.exists(p):
-            # skip nonexistent paths
-            continue
-
-        if os.path.isfile(p):
-            basename = os.path.basename(p)
-            fname = os.path.splitext(basename)
-            if not should_skip(exclude_item=fname,
-                               exclude_types=True,
-                               exclude_file_patterns=True):
-                all_files.append(p)
-        else:
-            # p is a directory
-            _collect_from_dir(p)
-
-    return all_files
-
-# requirements:
-#   pip install pdfplumber pdf2image pytesseract pillow
-#   # plus Tesseract binary (apt install tesseract-ocr or brew install tesseract)
 
 
 
